@@ -6,12 +6,15 @@ COG_SYS_FILE = "cogsys.c"
 COG_DEFAULT_NAMESPACE = "default"
 STORE="-store-"
 INDEX="-index-"
-INDEX_BLOCK_LEN=10
-INDEX_CAPACITY = 2000
+INDEX_BLOCK_BASE_LEN = 20 #max store address length
+INDEX_BLOCK_KEYBIT_LEN = int(INDEX_BLOCK_BASE_LEN/2)
+INDEX_BLOCK_LEN = INDEX_BLOCK_BASE_LEN + INDEX_BLOCK_KEYBIT_LEN
+INDEX_CAPACITY = 100003 # must be a prime number
 INDEX_LOAD_FACTOR = 80
 
 ''' TORQUE '''
 GRAPH_NODE_SET_TABLE_NAME = 'TOR_NODE_SET'
+GRAPH_EDGE_SET_TABLE_NAME = 'TOR_EDGE_SET'
 
 ''' CUSTOM COG DB PATH '''
 CUSTOM_COG_DB_PATH = None
@@ -42,6 +45,8 @@ def cog_data_dir(db_name):
 def cog_index(db_name, table_name, instance_id, index_id):
     return "/".join(cog_context()[0:-2]+[db_name,table_name+INDEX+instance_id+"-"+str(index_id)])
 
+def get_table_name(index_file_name):
+    return index_file_name.split(INDEX)[0]
 
 def index_id(index_name):
     return int(index_name.split("-")[-1])
@@ -57,15 +62,15 @@ logging_config = dict(
     version = 1,
     formatters = {
         'f': {'format':
-              '%(asctime)s %(name)-12s %(levelname)-8s %(message)s'}
+              '%(asctime)s %(name)-12s %(levelname)-8s [%(filename)s:%(lineno)s - %(funcName)10s()] %(message)s'}
         },
     handlers = {
         'h': {'class': 'logging.StreamHandler',
-              'formatter': 'f',
-              'level': logging.WARN}
+              'formatter': 'f'
+              }
         },
     root = {
         'handlers': ['h'],
         'level': logging.WARN,
-        },
-)
+        }
+)
\ No newline at end of file
