@@ -1,4 +1,4 @@
-
+from cog.core import Record
 from cog.database import Cog
 from cog import config
 import json
@@ -26,23 +26,25 @@ class TestDB(unittest.TestCase):
         config.COG_HOME = DIR_NAME
 
     def test_db(self):
-        data = ('user100','{"firstname":"Hari","lastname":"seldon"}')
+        data = Record('user100','{"firstname":"Hari","lastname":"seldon"}')
         cogdb = Cog(config=config)
         cogdb.create_namespace("test")
-        cogdb.create_or_load_table("db_test", "test")
+        cogdb.create_table("db_test", "test")
         cogdb.put(data)
         scanner = cogdb.scanner()
+        res = None
         for r in scanner:
             res = r
-        self.assertEqual(res, ('user100', '{"firstname":"Hari","lastname":"seldon"}'))
+        print(res)
+        self.assertTrue(data.is_equal_val(res))
         cogdb.close()
 
     def test_list_tables(self):
         cogdb = Cog(config=config)
         cogdb.create_namespace("test_ns")
-        cogdb.create_or_load_table("table1", "test_ns")
-        cogdb.create_or_load_table("table2", "test_ns")
-        cogdb.create_or_load_table("table3", "test_ns")
+        cogdb.create_table("table1", "test_ns")
+        cogdb.create_table("table2", "test_ns")
+        cogdb.create_table("table3", "test_ns")
         self.assertEqual(set(cogdb.list_tables()), {'table2', 'table3', 'table1'})
         cogdb.close()
 
